# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'diffractionUI.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets
import os
fn = os.path.join(os.path.dirname(__file__), "diffraction-icon.png")


class Ui_Diffraction(object):
    def setupUi(self, Diffraction):
        Diffraction.setObjectName("Diffraction")
        Diffraction.resize(1200, 873)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(fn), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Diffraction.setWindowIcon(icon)
        Diffraction.setIconSize(QtCore.QSize(24, 24))
        self.centralwidget = QtWidgets.QWidget(Diffraction)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.mplvl = QtWidgets.QGridLayout()
        self.mplvl.setObjectName("mplvl")
        self.gridLayout_2.addLayout(self.mplvl, 0, 0, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox.setMaximumSize(QtCore.QSize(350, 16777215))
        self.groupBox.setTitle("")
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.distance_button = QtWidgets.QPushButton(self.groupBox)
        self.distance_button.setObjectName("distance_button")
        self.gridLayout.addWidget(self.distance_button, 19, 0, 1, 6)
        self.tilt_axis_angle_entry = QtWidgets.QLineEdit(self.groupBox)
        self.tilt_axis_angle_entry.setObjectName("tilt_axis_angle_entry")
        self.gridLayout.addWidget(self.tilt_axis_angle_entry, 6, 6, 1, 3)
        self.space_group_label = QtWidgets.QLabel(self.groupBox)
        self.space_group_label.setObjectName("space_group_label")
        self.gridLayout.addWidget(self.space_group_label, 4, 0, 1, 3)
        self.precision_entry = QtWidgets.QLineEdit(self.groupBox)
        self.precision_entry.setObjectName("precision_entry")
        self.gridLayout.addWidget(self.precision_entry, 19, 6, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 8, 0, 1, 10)
        self.tilt_axis_angle_label = QtWidgets.QLabel(self.groupBox)
        self.tilt_axis_angle_label.setObjectName("tilt_axis_angle_label")
        self.gridLayout.addWidget(self.tilt_axis_angle_label, 6, 0, 1, 6)
        self.indice_entry = QtWidgets.QLineEdit(self.groupBox)
        self.indice_entry.setObjectName("indice_entry")
        self.gridLayout.addWidget(self.indice_entry, 2, 5, 1, 4)
        self.alpha_signBox = QtWidgets.QCheckBox(self.groupBox)
        self.alpha_signBox.setText("")
        self.alpha_signBox.setObjectName("alpha_signBox")
        self.gridLayout.addWidget(self.alpha_signBox, 14, 2, 1, 1)
        self.Button_reset_all = QtWidgets.QPushButton(self.groupBox)
        self.Button_reset_all.setObjectName("Button_reset_all")
        self.gridLayout.addWidget(self.Button_reset_all, 10, 6, 1, 4)
        self.Calib_box = QtWidgets.QComboBox(self.groupBox)
        self.Calib_box.setObjectName("Calib_box")
        self.gridLayout.addWidget(self.Calib_box, 5, 4, 1, 7)
        self.ListBox_theo = QtWidgets.QListWidget(self.groupBox)
        self.ListBox_theo.setObjectName("ListBox_theo")
        self.gridLayout.addWidget(self.ListBox_theo, 18, 0, 1, 10)
        self.remove_spot_button = QtWidgets.QPushButton(self.groupBox)
        self.remove_spot_button.setObjectName("remove_spot_button")
        self.gridLayout.addWidget(self.remove_spot_button, 27, 3, 1, 3)
        self.theta_signBox = QtWidgets.QCheckBox(self.groupBox)
        self.theta_signBox.setText("")
        self.theta_signBox.setObjectName("theta_signBox")
        self.gridLayout.addWidget(self.theta_signBox, 14, 9, 1, 1)
        self.tilt_a_entry = QtWidgets.QLineEdit(self.groupBox)
        self.tilt_a_entry.setObjectName("tilt_a_entry")
        self.gridLayout.addWidget(self.tilt_a_entry, 14, 1, 1, 1)
        self.SpaceGroup_box = QtWidgets.QComboBox(self.groupBox)
        self.SpaceGroup_box.setObjectName("SpaceGroup_box")
        self.gridLayout.addWidget(self.SpaceGroup_box, 4, 4, 1, 7)
        self.Calib_label = QtWidgets.QLabel(self.groupBox)
        self.Calib_label.setObjectName("Calib_label")
        self.gridLayout.addWidget(self.Calib_label, 5, 0, 1, 2)
        self.precision_label = QtWidgets.QLabel(self.groupBox)
        self.precision_label.setObjectName("precision_label")
        self.gridLayout.addWidget(self.precision_label, 19, 7, 1, 3)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 24, 0, 1, 2)
        self.tilt_b_entry = QtWidgets.QLineEdit(self.groupBox)
        self.tilt_b_entry.setObjectName("tilt_b_entry")
        self.gridLayout.addWidget(self.tilt_b_entry, 14, 5, 1, 1)
        self.abc_entry = QtWidgets.QLineEdit(self.groupBox)
        self.abc_entry.setObjectName("abc_entry")
        self.gridLayout.addWidget(self.abc_entry, 0, 5, 1, 6)
        self.Button_reset = QtWidgets.QPushButton(self.groupBox)
        self.Button_reset.setObjectName("Button_reset")
        self.gridLayout.addWidget(self.Button_reset, 9, 6, 1, 4)
        self.abc_label = QtWidgets.QLabel(self.groupBox)
        self.abc_label.setObjectName("abc_label")
        self.gridLayout.addWidget(self.abc_label, 0, 0, 1, 1)
        self.euler_listbox = QtWidgets.QListWidget(self.groupBox)
        self.euler_listbox.setObjectName("euler_listbox")
        self.gridLayout.addWidget(self.euler_listbox, 29, 0, 1, 11)
        self.alpha_label = QtWidgets.QLabel(self.groupBox)
        self.alpha_label.setObjectName("alpha_label")
        self.gridLayout.addWidget(self.alpha_label, 1, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 13, 0, 1, 3)
        self.beta_signBox = QtWidgets.QCheckBox(self.groupBox)
        self.beta_signBox.setText("")
        self.beta_signBox.setObjectName("beta_signBox")
        self.gridLayout.addWidget(self.beta_signBox, 14, 6, 1, 1)
        self.alpha_label_2 = QtWidgets.QLabel(self.groupBox)
        self.alpha_label_2.setObjectName("alpha_label_2")
        self.gridLayout.addWidget(self.alpha_label_2, 14, 0, 1, 1)
        self.tilt_z_entry = QtWidgets.QLineEdit(self.groupBox)
        self.tilt_z_entry.setObjectName("tilt_z_entry")
        self.gridLayout.addWidget(self.tilt_z_entry, 14, 8, 1, 1)
        self.z_label = QtWidgets.QLabel(self.groupBox)
        self.z_label.setObjectName("z_label")
        self.gridLayout.addWidget(self.z_label, 14, 7, 1, 1)
        self.beta_label = QtWidgets.QLabel(self.groupBox)
        self.beta_label.setObjectName("beta_label")
        self.gridLayout.addWidget(self.beta_label, 14, 4, 1, 1)
        self.add_spot_button = QtWidgets.QPushButton(self.groupBox)
        self.add_spot_button.setObjectName("add_spot_button")
        self.gridLayout.addWidget(self.add_spot_button, 27, 0, 1, 3)
        self.n_label = QtWidgets.QLabel(self.groupBox)
        self.n_label.setObjectName("n_label")
        self.gridLayout.addWidget(self.n_label, 3, 0, 1, 5)
        self.n_entry = QtWidgets.QLineEdit(self.groupBox)
        self.n_entry.setObjectName("n_entry")
        self.gridLayout.addWidget(self.n_entry, 3, 5, 1, 4)
        self.alphabetagamma_entry = QtWidgets.QLineEdit(self.groupBox)
        self.alphabetagamma_entry.setObjectName("alphabetagamma_entry")
        self.gridLayout.addWidget(self.alphabetagamma_entry, 1, 5, 1, 6)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 16, 0, 1, 4)
        self.do_not_guess_checkBox = QtWidgets.QCheckBox(self.groupBox)
        self.do_not_guess_checkBox.setObjectName("do_not_guess_checkBox")
        self.gridLayout.addWidget(self.do_not_guess_checkBox, 16, 4, 1, 7)
        self.diff_spot_Listbox = QtWidgets.QListWidget(self.groupBox)
        self.diff_spot_Listbox.setObjectName("diff_spot_Listbox")
        self.gridLayout.addWidget(self.diff_spot_Listbox, 26, 0, 1, 11)
        self.orientation_button = QtWidgets.QPushButton(self.groupBox)
        self.orientation_button.setObjectName("orientation_button")
        self.gridLayout.addWidget(self.orientation_button, 27, 6, 1, 5)
        self.ListBox_d_2 = QtWidgets.QListWidget(self.groupBox)
        self.ListBox_d_2.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.ListBox_d_2.setObjectName("ListBox_d_2")
        self.gridLayout.addWidget(self.ListBox_d_2, 9, 0, 3, 5)
        self.two_to_three_checkBox = QtWidgets.QCheckBox(self.groupBox)
        self.two_to_three_checkBox.setObjectName("two_to_three_checkBox")
        self.gridLayout.addWidget(self.two_to_three_checkBox, 11, 6, 1, 4)
        self.indice_label = QtWidgets.QLabel(self.groupBox)
        self.indice_label.setObjectName("indice_label")
        self.gridLayout.addWidget(self.indice_label, 2, 0, 1, 3)
        self.abc_label.raise_()
        self.indice_label.raise_()
        self.n_label.raise_()
        self.space_group_label.raise_()
        self.Calib_label.raise_()
        self.label.raise_()
        self.distance_button.raise_()
        self.diff_spot_Listbox.raise_()
        self.add_spot_button.raise_()
        self.ListBox_d_2.raise_()
        self.euler_listbox.raise_()
        self.label_4.raise_()
        self.remove_spot_button.raise_()
        self.orientation_button.raise_()
        self.SpaceGroup_box.raise_()
        self.Calib_box.raise_()
        self.n_entry.raise_()
        self.indice_entry.raise_()
        self.tilt_axis_angle_entry.raise_()
        self.tilt_axis_angle_label.raise_()
        self.alpha_label.raise_()
        self.alphabetagamma_entry.raise_()
        self.abc_entry.raise_()
        self.ListBox_theo.raise_()
        self.label_2.raise_()
        self.label_3.raise_()
        self.alpha_label_2.raise_()
        self.tilt_a_entry.raise_()
        self.alpha_signBox.raise_()
        self.beta_label.raise_()
        self.tilt_b_entry.raise_()
        self.beta_signBox.raise_()
        self.z_label.raise_()
        self.tilt_z_entry.raise_()
        self.theta_signBox.raise_()
        self.Button_reset_all.raise_()
        self.precision_entry.raise_()
        self.precision_label.raise_()
        self.Button_reset.raise_()
        self.do_not_guess_checkBox.raise_()
        self.two_to_three_checkBox.raise_()
        self.gridLayout_2.addWidget(self.groupBox, 0, 1, 1, 1)
        Diffraction.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(Diffraction)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1200, 23))
        self.menubar.setObjectName("menubar")
        self.menuSave = QtWidgets.QMenu(self.menubar)
        self.menuSave.setObjectName("menuSave")
        self.menuStructure = QtWidgets.QMenu(self.menubar)
        self.menuStructure.setObjectName("menuStructure")
        self.menuSpectrum = QtWidgets.QMenu(self.menubar)
        self.menuSpectrum.setObjectName("menuSpectrum")
        self.menuData = QtWidgets.QMenu(self.menubar)
        self.menuData.setObjectName("menuData")
        Diffraction.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(Diffraction)
        self.statusbar.setObjectName("statusbar")
        Diffraction.setStatusBar(self.statusbar)
        self.actionSave_figure = QtWidgets.QAction(Diffraction)
        self.actionSave_figure.setObjectName("actionSave_figure")
        self.actionCalculate_Schmid_factor = QtWidgets.QAction(Diffraction)
        self.actionCalculate_Schmid_factor.setObjectName("actionCalculate_Schmid_factor")
        self.actionCalculate_spectrum = QtWidgets.QAction(Diffraction)
        self.actionCalculate_spectrum.setObjectName("actionCalculate_spectrum")
        self.actionImport = QtWidgets.QAction(Diffraction)
        self.actionImport.setObjectName("actionImport")
        self.actionExport = QtWidgets.QAction(Diffraction)
        self.actionExport.setObjectName("actionExport")
        self.menuSave.addAction(self.actionSave_figure)
        self.menuSpectrum.addAction(self.actionCalculate_spectrum)
        self.menuData.addAction(self.actionImport)
        self.menuData.addAction(self.actionExport)
        self.menubar.addAction(self.menuSave.menuAction())
        self.menubar.addAction(self.menuStructure.menuAction())
        self.menubar.addAction(self.menuSpectrum.menuAction())
        self.menubar.addAction(self.menuData.menuAction())

        self.retranslateUi(Diffraction)
        QtCore.QMetaObject.connectSlotsByName(Diffraction)
        Diffraction.setTabOrder(self.abc_entry, self.alphabetagamma_entry)
        Diffraction.setTabOrder(self.alphabetagamma_entry, self.indice_entry)
        Diffraction.setTabOrder(self.indice_entry, self.n_entry)
        Diffraction.setTabOrder(self.n_entry, self.SpaceGroup_box)
        Diffraction.setTabOrder(self.SpaceGroup_box, self.Calib_box)
        Diffraction.setTabOrder(self.Calib_box, self.tilt_axis_angle_entry)
        Diffraction.setTabOrder(self.tilt_axis_angle_entry, self.ListBox_d_2)
        Diffraction.setTabOrder(self.ListBox_d_2, self.Button_reset)
        Diffraction.setTabOrder(self.Button_reset, self.Button_reset_all)
        Diffraction.setTabOrder(self.Button_reset_all, self.two_to_three_checkBox)
        Diffraction.setTabOrder(self.two_to_three_checkBox, self.tilt_a_entry)
        Diffraction.setTabOrder(self.tilt_a_entry, self.alpha_signBox)
        Diffraction.setTabOrder(self.alpha_signBox, self.tilt_b_entry)
        Diffraction.setTabOrder(self.tilt_b_entry, self.beta_signBox)
        Diffraction.setTabOrder(self.beta_signBox, self.tilt_z_entry)
        Diffraction.setTabOrder(self.tilt_z_entry, self.theta_signBox)
        Diffraction.setTabOrder(self.theta_signBox, self.do_not_guess_checkBox)
        Diffraction.setTabOrder(self.do_not_guess_checkBox, self.ListBox_theo)
        Diffraction.setTabOrder(self.ListBox_theo, self.distance_button)
        Diffraction.setTabOrder(self.distance_button, self.precision_entry)
        Diffraction.setTabOrder(self.precision_entry, self.diff_spot_Listbox)
        Diffraction.setTabOrder(self.diff_spot_Listbox, self.add_spot_button)
        Diffraction.setTabOrder(self.add_spot_button, self.remove_spot_button)
        Diffraction.setTabOrder(self.remove_spot_button, self.orientation_button)
        Diffraction.setTabOrder(self.orientation_button, self.euler_listbox)

    def retranslateUi(self, Diffraction):
        _translate = QtCore.QCoreApplication.translate
        Diffraction.setWindowTitle(_translate("Diffraction", "Diffraction pattern"))
        self.distance_button.setText(_translate("Diffraction", "Find diffraction spots"))
        self.space_group_label.setText(_translate("Diffraction", "Space group"))
        self.label.setText(_translate("Diffraction", "<html><head/><body><p><span style=\" font-weight:600;\">Dist., inclination</span></p></body></html>"))
        self.tilt_axis_angle_label.setText(_translate("Diffraction", "Diffraction-α tilt angle"))
        self.Button_reset_all.setText(_translate("Diffraction", "Reset view"))
        self.remove_spot_button.setText(_translate("Diffraction", "Remove"))
        self.Calib_label.setText(_translate("Diffraction", "Calibrations"))
        self.precision_label.setText(_translate("Diffraction", "precision"))
        self.label_4.setText(_translate("Diffraction", "<html><head/><body><p><span style=\" font-weight:600;\">Data</span></p></body></html>"))
        self.Button_reset.setText(_translate("Diffraction", "Reset points"))
        self.abc_label.setText(_translate("Diffraction", "a,b,c"))
        self.alpha_label.setText(_translate("Diffraction", "<html><head/><body><p>α,β,γ</p></body></html>"))
        self.label_3.setText(_translate("Diffraction", "<html><head/><body><p><span style=\" font-weight:600;\">Tilt angles/AC</span></p></body></html>"))
        self.alpha_label_2.setText(_translate("Diffraction", "α (°)"))
        self.z_label.setText(_translate("Diffraction", "θ (°)"))
        self.beta_label.setText(_translate("Diffraction", "β (°)"))
        self.add_spot_button.setText(_translate("Diffraction", "Add data"))
        self.n_label.setText(_translate("Diffraction", "Diffraction order"))
        self.label_2.setText(_translate("Diffraction", "<html><head/><body><p><span style=\" font-weight:600;\">g vectors</span></p></body></html>"))
        self.do_not_guess_checkBox.setText(_translate("Diffraction", "do not use g-vector guess"))
        self.orientation_button.setText(_translate("Diffraction", "Get orientation"))
        self.two_to_three_checkBox.setText(_translate("Diffraction", "2-to-3 beams"))
        self.indice_label.setText(_translate("Diffraction", "Max Indices"))
        self.menuSave.setTitle(_translate("Diffraction", "Open"))
        self.menuStructure.setTitle(_translate("Diffraction", "Structure"))
        self.menuSpectrum.setTitle(_translate("Diffraction", "Spectrum"))
        self.menuData.setTitle(_translate("Diffraction", "Data"))
        self.actionSave_figure.setText(_translate("Diffraction", "Open image"))
        self.actionCalculate_Schmid_factor.setText(_translate("Diffraction", "calculate Schmid factor"))
        self.actionCalculate_spectrum.setText(_translate("Diffraction", "Plot spectrum"))
        self.actionImport.setText(_translate("Diffraction", "Import"))
        self.actionExport.setText(_translate("Diffraction", "Export"))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'schmidUI.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Schmid(object):
    def setupUi(self, Schmid):
        Schmid.setObjectName("Schmid")
        Schmid.resize(343, 320)
        self.layoutWidget = QtWidgets.QWidget(Schmid)
        self.layoutWidget.setGeometry(QtCore.QRect(10, 10, 318, 298))
        self.layoutWidget.setObjectName("layoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.layoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.schmid_text = QtWidgets.QTextEdit(self.layoutWidget)
        self.schmid_text.setObjectName("schmid_text")
        self.gridLayout.addWidget(self.schmid_text, 6, 0, 1, 3)
        self.b_label = QtWidgets.QLabel(self.layoutWidget)
        self.b_label.setObjectName("b_label")
        self.gridLayout.addWidget(self.b_label, 0, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(self.layoutWidget)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 7, 0, 1, 2)
        self.T_label = QtWidgets.QLabel(self.layoutWidget)
        self.T_label.setObjectName("T_label")
        self.gridLayout.addWidget(self.T_label, 3, 0, 1, 1)
        self.b_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.b_entry.setObjectName("b_entry")
        self.gridLayout.addWidget(self.b_entry, 0, 1, 1, 1)
        self.T_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.T_entry.setObjectName("T_entry")
        self.gridLayout.addWidget(self.T_entry, 3, 1, 1, 1)
        self.n_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.n_entry.setObjectName("n_entry")
        self.gridLayout.addWidget(self.n_entry, 2, 1, 1, 1)
        self.n_label = QtWidgets.QLabel(self.layoutWidget)
        self.n_label.setObjectName("n_label")
        self.gridLayout.addWidget(self.n_label, 2, 0, 1, 1)
        self.schmid_factor_label = QtWidgets.QLabel(self.layoutWidget)
        self.schmid_factor_label.setText("")
        self.schmid_factor_label.setObjectName("schmid_factor_label")
        self.gridLayout.addWidget(self.schmid_factor_label, 4, 1, 1, 1)

        self.retranslateUi(Schmid)
        QtCore.QMetaObject.connectSlotsByName(Schmid)
        Schmid.setTabOrder(self.b_entry, self.n_entry)
        Schmid.setTabOrder(self.n_entry, self.T_entry)
        Schmid.setTabOrder(self.T_entry, self.schmid_text)
        Schmid.setTabOrder(self.schmid_text, self.buttonBox)

    def retranslateUi(self, Schmid):
        _translate = QtCore.QCoreApplication.translate
        Schmid.setWindowTitle(_translate("Schmid", "Schmid Factor"))
        self.b_label.setText(_translate("Schmid", "b"))
        self.T_label.setText(_translate("Schmid", "T"))
        self.n_label.setText(_translate("Schmid", "n"))
